Repository for Ecan allocation and usage Python tools
=============================================================

This git repository contains the Ecan allocation and usage Python tools and associated documentation.

.. Documentation
.. --------------
.. The primary documentation for the package can be found `here <http://hilltop-py.readthedocs.io>`_.

Installation
------------
EcanAlloUsageTools can be installed via pip or conda::

  pip install EcanAlloUsageTools

or::

  conda install -c mullenkamp EcanAlloUsageTools

The main dependencies are `Pandas <http://pandas.pydata.org/pandas-docs/stable/>`_ and pdsql.
